Extract Model Coefficients for fracreg
coef.fracreg.RdExtracts the estimated coefficients from a fitted fracreg model.
Usage
# S3 method for class 'fracreg'
coef(object, ...)
coef.fracreg.RdExtracts the estimated coefficients from a fitted fracreg model.
# S3 method for class 'fracreg'
coef(object, ...)