Extract Model Coefficients for fracreghet
coef.fracreghet.RdExtracts the estimated coefficients from a fitted fracreghet model.
Usage
# S3 method for class 'fracreghet'
coef(object, ...)
coef.fracreghet.RdExtracts the estimated coefficients from a fitted fracreghet model.
# S3 method for class 'fracreghet'
coef(object, ...)