Extract Model Coefficients for fracregmlogit
coef.fracregmlogit.RdExtracts the estimated coefficients from a fitted fracregmlogit model.
Usage
# S3 method for class 'fracregmlogit'
coef(object, ...)
coef.fracregmlogit.RdExtracts the estimated coefficients from a fitted fracregmlogit model.
# S3 method for class 'fracregmlogit'
coef(object, ...)