Extract Model Coefficients for fracregpd
coef.fracregpd.RdExtracts the estimated coefficients from a fitted fracregpd model.
Usage
# S3 method for class 'fracregpd'
coef(object, ...)
coef.fracregpd.RdExtracts the estimated coefficients from a fitted fracregpd model.
# S3 method for class 'fracregpd'
coef(object, ...)