Extract Model Coefficients for fracregridge
coef.fracregridge.RdExtracts the estimated coefficients from a fitted fracregridge model.
Usage
# S3 method for class 'fracregridge'
coef(object, ...)
coef.fracregridge.RdExtracts the estimated coefficients from a fitted fracregridge model.
# S3 method for class 'fracregridge'
coef(object, ...)