Extract the Number of Observations for fracreg
nobs.fracreg.RdExtracts the number of observations used to estimate a fracreg model.
Usage
# S3 method for class 'fracreg'
nobs(object, ...)
nobs.fracreg.RdExtracts the number of observations used to estimate a fracreg model.
# S3 method for class 'fracreg'
nobs(object, ...)