Extract the Number of Observations for fracreghet
nobs.fracreghet.RdExtracts the number of observations used to estimate a fracreghet model.
Usage
# S3 method for class 'fracreghet'
nobs(object, ...)
nobs.fracreghet.RdExtracts the number of observations used to estimate a fracreghet model.
# S3 method for class 'fracreghet'
nobs(object, ...)