Extract the Number of Observations for fracregmlogit
nobs.fracregmlogit.RdExtracts the number of observations used to estimate a fracregmlogit model.
Usage
# S3 method for class 'fracregmlogit'
nobs(object, ...)
nobs.fracregmlogit.RdExtracts the number of observations used to estimate a fracregmlogit model.
# S3 method for class 'fracregmlogit'
nobs(object, ...)