Extract the Number of Observations for fracregpd
nobs.fracregpd.RdExtracts the number of observations used to estimate a fracregpd model.
Usage
# S3 method for class 'fracregpd'
nobs(object, ...)
nobs.fracregpd.RdExtracts the number of observations used to estimate a fracregpd model.
# S3 method for class 'fracregpd'
nobs(object, ...)