Extract the Number of Observations for fracregridge
nobs.fracregridge.RdExtracts the number of observations used to estimate a fracregridge model.
Usage
# S3 method for class 'fracregridge'
nobs(object, ...)
nobs.fracregridge.RdExtracts the number of observations used to estimate a fracregridge model.
# S3 method for class 'fracregridge'
nobs(object, ...)