Predict Method for fracreg
predict.fracreg.RdPredicts conditional mean values from a fitted fracreg model.
Usage
# S3 method for class 'fracreg'
predict(object, newdata = NULL, ...)
predict.fracreg.RdPredicts conditional mean values from a fitted fracreg model.
# S3 method for class 'fracreg'
predict(object, newdata = NULL, ...)