Skip to contents

Predicts conditional mean values from a fitted fracregridge model.

Usage

# S3 method for class 'fracregridge'
predict(object, newdata = NULL, ...)

Arguments

object

A fitted model object of class fracregridge.

newdata

An optional data frame or matrix in which to look for variables with which to predict. If omitted, the fitted values are used.

...

Further arguments passed to or from other methods.

Value

A matrix or array of predicted values.