Predict Method for fracregpd
predict.fracregpd.RdPredicts conditional mean values from a fitted fracregpd model.
Usage
# S3 method for class 'fracregpd'
predict(object, newdata = NULL, ...)
predict.fracregpd.RdPredicts conditional mean values from a fitted fracregpd model.
# S3 method for class 'fracregpd'
predict(object, newdata = NULL, ...)