Predict Method for fracregridge
predict.fracregridge.RdPredicts conditional mean values from a fitted fracregridge model.
Usage
# S3 method for class 'fracregridge'
predict(object, newdata = NULL, ...)
predict.fracregridge.RdPredicts conditional mean values from a fitted fracregridge model.
# S3 method for class 'fracregridge'
predict(object, newdata = NULL, ...)